@@ -218,7 +218,7 @@ class TraversalMixin(JsonSerializableMixin):
                 mapper = class_mapper(self.__class__, compile=False)
                 rel_prop = mapper.get_property(attribute)
                 name = rel_prop.target.name
-                cls = self.__parent__.get(name)()
+                cls = self.__parent__.get_class(name)()
                 cls.__parent__ = self
 
                 return cls
@@ -238,7 +238,8 @@ class TraversalMixin(JsonSerializableMixin):
         # if we are returning a collection or a single instance
         if obj != None:
             try:
-                if not isinstance(obj, (str, unicode)):
+                ignore_types = (str, unicode, int, float,TraversalMixin)
+                if not isinstance(obj, ignore_types):
                     # is this is a collection
                     iter(obj)
                     col = ModelCollection(obj)
